============
Installation
============

The library uses Python 3.6 onwards.

To install the latest version via ``pip`` ::

    pip install -U mplsoccer

To install the latest version via ``Anaconda`` ::

    conda install -c conda-forge mplsoccer

You may also need to upgrade mplsoccer dependencies such as seaborn.
